# Changes

## v1.1.0

- added support for parsing and solving simple defaults
- added `--step` option to parametrize linear step size/exponential base for
  search algorithm of minimal upper bounds
- fixed a bug with user include for unbounded cardinalities
- fixed a bug with optimization in incremental bound solving
- minor fixes

## v1.0.0

- initial Release
